@@ -15,6 +15,7 @@
 #
 # Copyright 2014-2015  Jon Lund Steffensen <jon_steffensen@uri.edu>
 # Copyright 2018-2020  Jing Wang <wjingsjtu@gmail.com>
+# Copyright 2020-2021  Elysha Sameth <esameth1@uri.edu>
 
 # -*- coding: utf-8 -*-
 
@@ -249,8 +250,8 @@ class ModelMappingCommand(Command):
                     gene_map[source] = target
 
         # Check models
-        if (not (model1.check_reaction_compounds()
-                 and model2.check_reaction_compounds())):
+        if (not (model1.check_reaction_compounds() and
+                 model2.check_reaction_compounds())):
             quit((
                 '\nError: '
                 'equations have something not listed in compounds.yaml, '
@@ -276,8 +277,8 @@ class ModelMappingCommand(Command):
         t = time.time()
         # Write out ROC curve results
         if actual_compound_mapping is not None:
-            with open(self._args.outpath
-                      + '/roc/compound_bayes.tsv', 'w') as f:
+            with open(self._args.outpath +
+                      '/roc/compound_bayes.tsv', 'w') as f:
                 write_roc_curve(f, cpd_bayes_pred.model1.compounds,
                                 cpd_bayes_pred.model2.compounds,
                                 cpd_bayes_pred,
@@ -314,8 +315,8 @@ class ModelMappingCommand(Command):
         t = time.time()
         # Write out ROC curve results
         if actual_reaction_mapping is not None:
-            with open(self._args.outpath
-                      + '/roc/reaction_bayes.tsv', 'w') as f:
+            with open(self._args.outpath +
+                      '/roc/reaction_bayes.tsv', 'w') as f:
                 write_roc_curve(f, rxn_bayes_pred.model1.reactions,
                                 rxn_bayes_pred.model2.reactions,
                                 rxn_bayes_pred,
@@ -367,23 +368,36 @@ class ModelMappingCommand(Command):
         # iterate through reaction mapping
         for rmap in curator.reaction_map.iterrows():
             # skip already curated reactions
-            if (curator.reaction_checked(rmap[0])
-                    or curator.reaction_ignored(rmap[0][0])):
+            if (curator.reaction_checked(rmap[0]) or
+                    curator.reaction_ignored(rmap[0][0])):
                 continue
+            print('You have mapped %i reactions. '
+                  'There are %i reactions unmapped.'
+                  % (curator.num_curated_reactions,
+                     curator.num_curated_reactions_left))
+            print('\n')
             # check the compound mapping in current reaction
             compounds = curation.search_reaction(model1, [rmap[0][0]])
             compounds = [c.name for c in next(compounds)]
             dest_compounds = curation.search_reaction(model2, [rmap[0][1]])
             dest_compounds = [c.name for c in next(dest_compounds)]
+            print('\n', '*' * 60, '\n')
             print('Below are the compound mapping involved:\n')
             for compound in compounds:
                 for cmap in curator.compound_map.loc[compound].iterrows():
-                    if (cmap is None
-                            or cmap[0] not in dest_compounds
-                            or curator.compound_checked((compound, cmap[0]))
-                            or curator.compound_ignored(compound)):
+                    if (cmap is None or
+                            cmap[0] not in dest_compounds or
+                            curator.compound_checked((compound, cmap[0])) or
+                            curator.compound_ignored(compound)):
                         continue
+                    print('You have mapped %i compounds. '
+                          'There are %i compounds unmapped.'
+                          % (curator.num_curated_compounds,
+                             curator.num_curated_compounds_left))
+                    print('\n')
+                    print('-' * 30)
                     print(cmap[1])
+                    print('-' * 30)
                     print('\n')
                     curation.search_compound(model1, [compound])
                     curation.search_compound(model2, [cmap[0]])
@@ -407,6 +421,8 @@ class ModelMappingCommand(Command):
                                 'c',
                                 True
                             )
+                            curator.num_curated_compounds += 1
+                            curator.num_curated_compounds_left -= 1
                             break
                         if ask.lower() == 'ignore':
                             curator.add_ignore(compound, 'c')
@@ -418,8 +434,15 @@ class ModelMappingCommand(Command):
                             curator.save()
 
                     print('\n')
+            print('You have mapped %i reactions. '
+                  'There are %i reactions unmapped.'
+                  % (curator.num_curated_reactions,
+                     curator.num_curated_reactions_left))
+            print('\n')
             print('Here is the reaction mapping:')
+            print('-' * 30)
             print(rmap[1])
+            print('-' * 30)
             print('\n')
             compounds = curation.search_reaction(model1, [rmap[0][0]])
             compounds = [c for c in next(compounds)]
@@ -469,6 +492,8 @@ class ModelMappingCommand(Command):
                     break
                 if ask.lower() == 'y':
                     curator.add_mapping(rmap[0], 'r', True)
+                    curator.num_curated_reactions += 1
+                    curator.num_curated_reactions_left -= 1
                     break
                 if ask.lower() == 'ignore':
                     curator.add_ignore(rmap[0][0], 'r')
@@ -478,15 +503,21 @@ class ModelMappingCommand(Command):
                     exit(0)
                 if ask.lower() == 'save':
                     curator.save()
-            print('\n', '=' * 50, '\n')
+            print('\n', '=' * 60, '\n')
         curator.save()
 
     def _curate_compound(self, curator, model1, model2):
         for cmap in curator.compound_map.iterrows():
-            if (curator.compound_checked(cmap[0])
-                    or curator.compound_ignored(cmap[0][0])):
+            if (curator.compound_checked(cmap[0]) or
+                    curator.compound_ignored(cmap[0][0])):
                 continue
+            print('You have mapped %i compounds. '
+                  'There are %i compounds unmapped.'
+                  % (curator.num_curated_compounds,
+                     curator.num_curated_compounds_left))
+            print('-' * 30)
             print(cmap[1])
+            print('-' * 30)
             print('\n')
             curation.search_compound(model1, [cmap[0][0]])
             curation.search_compound(model2, [cmap[0][1]])
@@ -510,6 +541,8 @@ class ModelMappingCommand(Command):
                         'c',
                         True
                     )
+                    curator.num_curated_compounds += 1
+                    curator.num_curated_compounds_left -= 1
                     break
                 if ask.lower() == 'ignore':
                     curator.add_ignore(cmap[0][0], 'c')
@@ -519,7 +552,7 @@ class ModelMappingCommand(Command):
                     exit(0)
                 if ask.lower() == 'save':
                     curator.save()
-            print('\n', '=' * 50, '\n')
+            print('\n', '=' * 60, '\n')
 
     def _translate_id(self):
         """Translate ids"""
