@@ -16,6 +16,7 @@
 # Copyright 2014-2015  Jon Lund Steffensen <jon_steffensen@uri.edu>
 # Copyright 2018-2020  Jing Wang <wjingsjtu@gmail.com>
 # Copyright 2015-2020  Keith Dufault-Thompson <keitht547@my.uri.edu>
+# Copyright 2020-2021  Elysha Sameth <esameth1@uri.edu>
 
 from __future__ import print_function
 from __future__ import division
@@ -78,14 +79,23 @@ class Curator(object):
         self.ignore_compound = read_ignore(self.ignore_compound_file)
         self.ignore_reaction = read_ignore(self.ignore_reaction_file)
 
+        self.num_curated_compounds = len(self.curated_compound_map.index)
+        self.num_curated_compounds_left = \
+            self.compound_map.index.get_level_values(0).nunique() - \
+            self.num_curated_compounds
+        self.num_curated_reactions = len(self.curated_reaction_map.index)
+        self.num_curated_reactions_left = \
+            self.reaction_map.index.get_level_values(0).nunique() - \
+            self.num_curated_reactions
+
     def reaction_checked(self, id):
         """Return True if reaction pair has been checked.
 
         Args:
             id: one reaction id or a tuple of id pair
         """
-        return (id in self.curated_reaction_map.index
-                or id in self.false_reaction_map.index)
+        return (id in self.curated_reaction_map.index or
+                id in self.false_reaction_map.index)
 
     def reaction_ignored(self, id):
         """Return True if reaction id is in ignore list."""
@@ -97,8 +107,8 @@ class Curator(object):
         Args:
             id: one compound id or a tuple of id pair
         """
-        return (id in self.curated_compound_map.index
-                or id in self.false_compound_map.index)
+        return (id in self.curated_compound_map.index or
+                id in self.false_compound_map.index)
 
     def compound_ignored(self, id):
         """Return True if compound id is in ignore list."""
@@ -225,11 +235,11 @@ def search_compound(model, id):
     # Show results
     for compound in selected_compounds:
         props = set(compound.properties) - {'id'}
+        if compound.filemark is not None:
+            print('Defined in {}'.format(compound.filemark))
         print('id: {}'.format(compound.id))
         for prop in sorted(props):
             print('{}: {}'.format(prop, compound.properties[prop]))
-        if compound.filemark is not None:
-            print('Defined in {}'.format(compound.filemark))
         print('\n')
 
 
@@ -249,6 +259,8 @@ def search_reaction(model, ids):
     # Show results
     for reaction in selected_reactions:
         props = set(reaction.properties) - {'id', 'equation'}
+        if reaction.filemark is not None:
+            print('Defined in {}'.format(reaction.filemark))
         print('id: {}'.format(reaction.id))
         print('equation: {}'.format(
             reaction.equation))
@@ -259,7 +271,5 @@ def search_reaction(model, ids):
                 translated_equation))
         for prop in sorted(props):
             print('{}: {}'.format(prop, reaction.properties[prop]))
-        if reaction.filemark is not None:
-            print('Defined in {}'.format(reaction.filemark))
         print('\n')
         yield [c for c, v in reaction.equation.compounds]
